@@ -1,33 +1,10 @@
 /** -*- c++ -*-
  * progressdialog.cpp
  *
- *  Copyright (c) 2004 Till Adam <adam@kde.org>,
- *                     David Faure <faure@kde.org>
+ *  SPDX-FileCopyrightText: 2004 Till Adam <adam@kde.org>
+ *  SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  In addition, as a special exception, the copyright holders give
- *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
- *  combinations including the two.  You must obey the GNU General
- *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
- *  your version of the file, but you are not obligated to do so.  If
- *  you do not wish to do so, delete this exception statement from
- *  your version.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "progressdialog.h"
@@ -140,7 +117,7 @@ TransactionItemView::TransactionItemView(QWidget *parent, const QString &name)
     setObjectName(name);
     setFrameStyle(NoFrame);
     mBigBox = new QWidget(this);
-    QVBoxLayout *mBigBoxVBoxLayout = new QVBoxLayout(mBigBox);
+    auto *mBigBoxVBoxLayout = new QVBoxLayout(mBigBox);
     mBigBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     setWidget(mBigBox);
     setWidgetResizable(true);
@@ -149,7 +126,7 @@ TransactionItemView::TransactionItemView(QWidget *parent, const QString &name)
 
 TransactionItem *TransactionItemView::addTransactionItem(ProgressItem *item, bool first)
 {
-    TransactionItem *ti = new TransactionItem(mBigBox, item, first);
+    auto *ti = new TransactionItem(mBigBox, item, first);
     mBigBox->layout()->addWidget(ti);
 
     resize(mBigBox->width(), mBigBox->height());
@@ -208,7 +185,7 @@ void TransactionItemView::slotLayoutFirstItem()
      be the first item very shortly. That's the one we want to remove the
      hline for.
     */
-    TransactionItem *ti = mBigBox->findChild<KPIM::TransactionItem *>(QStringLiteral("TransactionItem"));
+    auto *ti = mBigBox->findChild<KPIM::TransactionItem *>(QStringLiteral("TransactionItem"));
     if (ti) {
         ti->hideHLine();
     }
@@ -218,10 +195,9 @@ void TransactionItemView::slotLayoutFirstItem()
 
 TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first)
     : QWidget(parent)
-    , mCancelButton(nullptr)
     , mItem(item)
 {
-    QVBoxLayout *vboxLayout = new QVBoxLayout(this);
+    auto *vboxLayout = new QVBoxLayout(this);
     vboxLayout->setSpacing(2);
     vboxLayout->setContentsMargins(2, 2, 2, 2);
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -233,7 +209,7 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
     layout()->addWidget(mFrame);
 
     QWidget *h = new QWidget(this);
-    QHBoxLayout *hHBoxLayout = new QHBoxLayout(h);
+    auto *hHBoxLayout = new QHBoxLayout(h);
     hHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hHBoxLayout->setSpacing(5);
     layout()->addWidget(h);
