@@ -1,38 +1,14 @@
 /*
   statusbarprogresswidget.cpp
 
-  (C) 2004 Till Adam <adam@kde.org>
-           Don Sanders
-           David Faure <dfaure@kde.org>
+  SPDX-FileCopyrightText: 2004 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2004 Don Sanders
+  SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-  Copyright 2004 David Faure <faure@kde.org>
   Includes StatusbarProgressWidget which is based on KIOLittleProgressDlg
-  by Matt Koss <koss@miesto.sk>
+  by SPDX-FileCopyrightText: Matt Koss <koss@miesto.sk>
 
-  KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  KMail is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt.  If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "statusbarprogresswidget.h"
@@ -46,7 +22,6 @@ using KPIM::ProgressManager;
 #include <KLocalizedString>
 
 #include <QEvent>
-#include <QFrame>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QMouseEvent>
@@ -64,7 +39,7 @@ StatusbarProgressWidget::StatusbarProgressWidget(ProgressDialog *progressDialog,
     , mProgressDialog(progressDialog)
 {
     int w = fontMetrics().boundingRect(QStringLiteral(" 999.9 kB/s 00:00:01 ")).width() + 8;
-    QHBoxLayout *boxLayout = new QHBoxLayout(this);
+    auto *boxLayout = new QHBoxLayout(this);
     boxLayout->setObjectName(QStringLiteral("boxLayout"));
     boxLayout->setContentsMargins(0, 0, 0, 0);
     boxLayout->setSpacing(0);
@@ -281,7 +256,7 @@ void StatusbarProgressWidget::slotClean()
 bool StatusbarProgressWidget::eventFilter(QObject *obj, QEvent *ev)
 {
     if (ev->type() == QEvent::MouseButtonPress) {
-        QMouseEvent *e = static_cast<QMouseEvent *>(ev);
+        auto *e = static_cast<QMouseEvent *>(ev);
 
         if (e->button() == Qt::LeftButton && mMode == Progress) {      // toggle view on left mouse button
             // Consensus seems to be that we should show/hide the fancy dialog when the user
